/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitBDecay.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2009 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a deltaT PDF for B decays 
// produced at the Y(4S) resonance.  
//
// Most general description of B decay time distribution with effects of 
// CP violation, mixing and life time differences. 

#include "AFit/AFitBDecay.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooBDecay.hh"
#else
#include "RooBDecay.h"
#endif

#include "TIterator.h"

ClassImp(AFitBDecay)
  ;

AFitBDecay::AFitBDecay(RooAbsReal& x, TString name)
  : 
  _tau(name+"_tau", "lifetime", 1.54, 1.0, 2.0) ,
  _dgamma(name+"_dgamma", "DeltaGamma", 0.0, -0.2, 0.2) ,
  _f0("f0", "Cosh Coefficient", 0.0, -1.0, 1.0),
  _f1("f1", "Sinh Coefficient", 0.0, -1.0, 1.0),
  _f2("f2", "Cos Coefficient", 0.0, -1.0, 1.0),
  _f3("f3", "Sin Coefficient", 0.0, -1.0, 1.0),
  _dm(name+"_dm", "delta m", 0.54, 0.3, 0.7) ,
  _type(name + "_type", "basis type", "DoubleSided"),
  _resolutionModelName(name+"_resolution_model", "Resolution Model", "Resolution")
 {
  // Constructor
  _name     = name;

  _t = (RooRealVar*)&x;

  varSet.addOwned(_tau);
  varSet.addOwned(_dgamma);
  varSet.addOwned(_f0);
  varSet.addOwned(_f1);
  varSet.addOwned(_f2);
  varSet.addOwned(_f3);
  varSet.addOwned(_dm);
  varSet.addOwned(_type);
  varSet.addOwned(_resolutionModelName);

  readDataCard();
}

AFitBDecay::~AFitBDecay() {
}

void AFitBDecay::buildPdf() {
  // Build the Pdf

  _theResolutionModel = dynamic_cast<RooResolutionModel*>(globalConfig.find(_resolutionModelName.getVal()));
  if(!_theResolutionModel) {
    cout << "  Resolution Model " << _resolutionModelName.getVal() << " does not exist" << endl;
    return;
  } else {
    cout << "  Resolution Model " << _resolutionModelName.getVal() << " has been found and will be used (address = " << _theResolutionModel << ")" <<endl;
  }

  TString thisType = _type.getVal();

  if(!thisType.CompareTo("DoubleSided", TString::kExact) ) {
    cout << "making pdf with double sided basis" << endl;
    _thePdf = new RooBDecay(_name,"deltat PDF: double sided",*_t,  _tau, _dgamma, _f0, _f1, _f2, _f3, _dm,
				 *_theResolutionModel, RooBDecay::DoubleSided);
  }
  else if(!thisType.CompareTo("SingleSided", TString::kExact) ) {
    cout << "making pdf with single sided basis" << endl;
    _thePdf = new RooBDecay(_name,"deltat PDF: double sided",*_t,  _tau, _dgamma, _f0, _f1, _f2, _f3, _dm,
				 *_theResolutionModel, RooBDecay::SingleSided);
  }
  else if(!thisType.CompareTo("Flipped", TString::kExact) ) {
    cout << "making pdf with flipped basis" << endl;
    _thePdf = new RooBDecay(_name,"deltat PDF: double sided",*_t,  _tau, _dgamma, _f0, _f1, _f2, _f3, _dm,
				 *_theResolutionModel, RooBDecay::Flipped);
  } else {
    cout << "unknown basis for " << ClassName() << " _type = " << _type.getVal() << " " << _thePdf << endl;
    _thePdf = 0;
  }

}

