/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitBreitWigner.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Sigmoid distribution.

#include "AFit/AFitBreitWigner.hh"
#ifdef __BABARROOFIT__
// RooFit includes
  #include "RooFitCore/RooBreitWigner.hh"
#else
// RooFit includes
  #include "RooBreitWigner.h"
#endif

#include "TIterator.h"

ClassImp(AFitBreitWigner)
  ;

AFitBreitWigner::AFitBreitWigner(RooAbsReal& x, TString name)
  : m0(name+"m0", "mass", 0.770, 0.0, 10.0)
    , Gamma(name+"Gamma", "width", 0.150, 0.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;
  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      m0.setRange(var->getMin(), var->getMax());
    }
  }

  varSet.addOwned(m0);
  varSet.addOwned(Gamma);

  readDataCard();
}

void AFitBreitWigner::buildPdf() {
  _thePdf = new RooBreitWigner(_name, "Breit Wigner PDF", *_x, m0, Gamma);
}

