/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitExponential.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds an Exponential PDF distribution.

#include "AFit/AFitExponential.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooExponential.hh"
#else
#include "RooExponential.h"
#endif

ClassImp(AFitExponential)
  ;

AFitExponential::AFitExponential(RooAbsReal& x, TString name)
  : constant(name+"constant", "Constant of Exponential", 1.0, -10.0, 10.0),
    fitLifetime(name+"fitLifetime", "fit for the lifetime = 1/constant"),
    exponent(name+"exponent", "exponent = 1/lifetime", "-1/@0", constant)
 {
  // Constructor
  _name     = name;

  _x = &x;

  fitLifetime.defineType("false");
  fitLifetime.defineType("true");
  fitLifetime.setLabel("false");

  varSet.add(constant);
  varSet.add(fitLifetime);


  readDataCard();
}

void AFitExponential::buildPdf() {
  // Build the Pdf
  if(fitLifetime == "true") {
    _thePdf = new RooExponential(_name, "Exponential PDF", *_x, exponent);
  } else {
    _thePdf = new RooExponential(_name, "Exponential PDF", *_x, constant);
  }
}

