/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitGaussian.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Gaussian distribution.
// If asymmetricWidth = true, then the widths above
// and below the mean are allowed to be different.

#include "AFit/AFitGaussian.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooGaussian.hh"
#include "RooFitModels/RooBifurGauss.hh"
#else
#include "RooGaussian.h"
#include "RooBifurGauss.h"
#endif

#include "TIterator.h"

ClassImp(AFitGaussian)
  ;

AFitGaussian::AFitGaussian(RooAbsReal& x, TString name)
  : mean(name+"mean", "Mean of Gaussian", 0.0, -1.0, 1.0)
    , width(name+"width", "Width of Gaussian", 1.0, 0.0, 10.0)
    , widthL(name+"widthL", "Width of asymmetric Gaussian (Left)", 1.0, 0.0, 10.0)
    , widthR(name+"widthR", "Width of asymmetric Gaussian (Right)", 1.0, 0.0, 10.0)
    , asymmetricWidth(name+"asymmetricWidth", "Use Asymmetric widths?")
 {
  // Constructor
  _name     = name;

  _x = &x;
  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      mean.setRange(var->getMin(), var->getMax());
      width.setRange(0.0,  var->getMax()-var->getMin());
      widthL.setRange(0.0, var->getMax()-var->getMin());
      widthR.setRange(0.0, var->getMax()-var->getMin());
    }
  }
  asymmetricWidth.defineType("true");
  asymmetricWidth.defineType("false");
  asymmetricWidth.setLabel("false");

  varSet.addOwned(mean);
  varSet.addOwned(width);
  varSet.addOwned(widthL);
  varSet.addOwned(widthR);
  varSet.addOwned(asymmetricWidth);

  readDataCard();
}

void AFitGaussian::buildPdf() {
  // Build the Pdf
  if (asymmetricWidth=="true") {
    _thePdf = new RooBifurGauss(_name, "Asymmetric Gaussian PDF", *_x, mean, widthL, widthR);
  } else {
    _thePdf = new RooGaussian(_name, "Gaussian PDF", *_x, mean, width);
  }
}

