/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitHelicityPdf.cc
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [PDF] --
// Implementation of a RooAbsPdf Helicity PDF
//
#include <math.h>

#include "AFit/AFitHelicityPdf.hh"
#ifdef __BABARROOFIT__
#include "RooFitCore/RooAbsReal.hh"
#include "RooFitCore/RooRealVar.hh"
#else
#include "RooAbsReal.h"
#include "RooRealVar.h"
#endif

ClassImp(AFitHelicityPdf)

AFitHelicityPdf::AFitHelicityPdf(const char *name, const char *title, RooAbsReal& _x, Bool_t & _type ) :
  RooAbsPdf(name, title),
  x("x", "Dependent", this, _x),
  type(_type)
{

}

AFitHelicityPdf::AFitHelicityPdf(const AFitHelicityPdf& other, const char* name) :
  RooAbsPdf(other, name), x("x", this, other.x), type(other.type)
{
}

Double_t AFitHelicityPdf::evaluate() const {
  double f(0);
  f = x*x; // have a cos^2 theta distribution as default

   if(!type) { // for use with x = costheta_hel
    f = 1 - x * x;
  }

  return f;
}

