/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitLandau.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Landau distribution

#include "AFit/AFitLandau.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooLandau.hh"
#else
#include "RooLandau.h"
#endif

ClassImp(AFitLandau)
  ;

AFitLandau::AFitLandau(RooAbsReal& x, TString name)
  : mean(name+"mean", "Mean of Landau", 0.0, -10.0, 10.0)
    , sigma(name+"sigma", "Sigma of Landau", 1.0, 0.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;
  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      mean.setRange(var->getMin(), var->getMax());
      sigma.setRange(0.0,  var->getMax()-var->getMin());
    }
  }

  varSet.add(mean);
  varSet.add(sigma);

  readDataCard();
}

void AFitLandau::buildPdf() {
  // Build the Pdf
    _thePdf = new RooLandau(_name, "Landau PDF", *_x, mean, sigma);
}

