/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitSigmoid.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Sigmoid distribution.

#include "AFit/AFitSigmoid.hh"
#include "AFit/AFitSigmoidPdf.hh"
#ifdef __BABARROOFIT__
// RooFit includes
#else
// RooFit includes
#endif

#include "TIterator.h"

ClassImp(AFitSigmoid)
  ;

AFitSigmoid::AFitSigmoid(RooAbsReal& x, TString name)
  : a(name+"a", "exponent scale factor", 1.0, -10.0, 10.0)
    , b(name+"b", "x-offset", 0.0, -10.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;
  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      a.setRange(var->getMin(), var->getMax());
      b.setRange(var->getMin(), var->getMax());
    }
  }

  varSet.addOwned(a);
  varSet.addOwned(b);

  readDataCard();
}

void AFitSigmoid::buildPdf() {
  _thePdf = new AFitSigmoidPdf(_name, "Sigmoid PDF", *_x, a, b);
}

