void cpfit_tagging() {
  //
  // Make a signal deltat model, with tag category splitting
  //
  AFitMaster master("AFit/example/cpfit_tagging.txt");
  RooAbsPdf * pdf = master.getSimPdf();

  //
  // Extract variables and categories in order to prepare a prototype data set
  // to generate toy data.
  //
  RooArgSet * compSet = (RooArgSet*)pdf->getComponents();
  RooArgSet * parSet = (RooArgSet*)pdf->getParameters(compSet);

  RooRealVar * deltat = (RooRealVar*)parSet->find("deltat");
  RooCategory * btag = (RooCategory*)parSet->find("signal_deltat_tag");
  RooCategory * tagcat = (RooCategory*)parSet->find("signal_deltat_cat");
  deltat->SetTitle("#Delta t (ps)");

  // 
  // Generate a Prototype data set of 10K events for fitting and plotting
  //
  RooArgSet & aset = master.getCondVarSet();
  RooRealVar * deltatErr = (RooRealVar*)aset.find("deltatErr");

  //
  // use a landau function to model the error on deltat for this example 
  //
  AFitLandau land(*deltatErr, "land");
  land.mean.setVal(1.1);
  land.sigma.setVal(0.2);
  RooAbsPdf * landPDF = land.getPdf();
  RooDataSet * protoDTE = (RooDataSet*)landPDF->generate(RooArgSet(*deltatErr), 10000);
  protoDTE->Print("v");

  //
  // Add the B tag and flavour tag category information to the prototype data set
  //
  btag->setIndex(+1);
  RooDataSet tagProto("tagProto", "tagset", RooArgSet(*btag,*tagcat));
  for(int i=0; i < 5000; i++) {
    if(i < 500) tagcat->setLabel("Lepton");
    else if(i < 1100) tagcat->setLabel("Kaon1");
    else if(i < 1700) tagcat->setLabel("Kaon2");
    else if(i < 2400) tagcat->setLabel("KaonPion");
    else if(i < 3400) tagcat->setLabel("Pion");
    else if(i < 4000) tagcat->setLabel("Other");
    else tagcat->setLabel("NoTag");
    tagProto.add( RooArgSet(*btag, *tagcat) );
  }
  btag->setIndex(-1);
  for(int i=0; i < 5000; i++) {
    if(i < 500) tagcat->setLabel("Lepton");
    else if(i < 1100) tagcat->setLabel("Kaon1");
    else if(i < 1700) tagcat->setLabel("Kaon2");
    else if(i < 2400) tagcat->setLabel("KaonPion");
    else if(i < 3400) tagcat->setLabel("Pion");
    else if(i < 4000) tagcat->setLabel("Other");
    else tagcat->setLabel("NoTag");
    tagProto.add( RooArgSet(*btag, *tagcat) );
  }

  cout << "the tagging prototype data set has been generated" << endl;
  tagProto.Print("v");

  cout << "Now merging datasets" << endl;
  protoDTE.merge(&tagProto);
  cout << "the prototype data set has been generated" << endl;
  protoDTE.Print("v");

  // 
  // Generate the data set for fitting and plotting
  //
  RooDataSet * data = (RooDataSet*)pdf->generate(RooArgSet(*deltat), *protoDTE, 10000);
  data.SetName("data");
  cout << "the following data set has been generated" << endl;
  data->Print("v");


  RooFitResult * r =   pdf.fitTo(*data, "etrh");

  //
  // Plot the resulting resolution function
  //
  AFitProjectionPlot plotter;
  RooPlot * frame = plotter.makeAsymmetryPlot(*deltat, *btag, data, pdf, protoDTE);

  frame.Draw();
  c1.Print("AFit/example/cpfit_tagging.eps");
}
