void rareBdecay() {

  /*
   * Test Model of me-de fit for a 3 component likelihood
   */

  AFitMaster master("AFit/example/rareBdecay.txt");
  RooAbsPdf * pdf = master.getPdf();

  ofstream out("mes_de_model_new.txt");
  master.writeDataCard(out);
  out.close();

  RooArgSet * compSet = pdf->getComponents();
  RooArgSet * parSet  = pdf->getParameters(compSet);
  cout << "Model Parameter Set:" << endl;
  parSet.Print("v");

  RooRealVar * bMes = (RooRealVar*)parSet->find("bMes");
  RooRealVar * bDeltaE = (RooRealVar*)parSet->find("bDeltaE");

  RooAbsPdf * signalpdf = compSet->find("signal");
  RooAbsPdf * continuumpdf = compSet->find("continuum");
  RooAbsPdf * Bbg0pdf = compSet->find("Bbg0");

  cout << "Generating Data" << endl;
  RooDataSet * data = 0;
  RooDataSet * sigdata = 0;
  RooDataSet * bgdata = 0;
  RooDataSet * cdata = 0;

  AFitToy toyUtil;
  toyUtil.setPoisson(kFALSE);
  //   data    = toyUtil.generateToySample("AFit/example/rareBdecay.txt");
  data    = toyUtil.generateToySample(pdf, RooArgSet(*bMes, *bDeltaE), 2550);
  sigdata = toyUtil.generateToySample(signalpdf, RooArgSet(*bMes, *bDeltaE), 500);
  bgdata  = toyUtil.generateToySample(Bbg0pdf, RooArgSet(*bMes, *bDeltaE), 50);
  cdata   = toyUtil.generateToySample(continuumpdf, RooArgSet(*bMes, *bDeltaE), 2000);

  cout << "Starting to Plot" << endl;
  AFitProjectionPlot plotter;
  RooPlot * frame_bMes    = plotter.makePlot(*bMes, data, pdf);
  RooPlot * frame_bDeltaE = plotter.makePlot(*bDeltaE, data, pdf);

  RooPlot * framecut_bMes    = plotter.makePlot("abs(bDeltaE)<0.1", *bMes, data, pdf);
  RooPlot * framecut_bDeltaE = plotter.makePlot("bMes>5.27", *bDeltaE, data, pdf);

  RooPlot * frame_sigbMes    = plotter.makePlot(*bMes,    sigdata, signalpdf);
  RooPlot * frame_sigbDeltaE = plotter.makePlot(*bDeltaE, sigdata, signalpdf);

  RooPlot * frame_contbMes    = plotter.makePlot(*bMes,    cdata,    continuumpdf);
  RooPlot * frame_contbDeltaE = plotter.makePlot(*bDeltaE, cdata, continuumpdf);

  RooPlot * frame_Bbg0bMes    = plotter.makePlot(*bMes,    bgdata, Bbg0pdf);
  RooPlot * frame_Bbg0bDeltaE = plotter.makePlot(*bDeltaE, bgdata, Bbg0pdf);

  TCanvas can("can", "");
  can.Divide(2,5);
  can.cd(1);
  frame_bMes->Draw();

  can.cd(2);
  frame_bDeltaE->Draw();

  can.cd(3);
  frame_sigbMes->Draw();

  can.cd(4);
  frame_sigbDeltaE->Draw();

  can.cd(5);
  frame_contbMes->Draw();

  can.cd(6);
  frame_contbDeltaE->Draw();

  can.cd(7);
  frame_Bbg0bMes->Draw();

  can.cd(8);
  frame_Bbg0bDeltaE->Draw();

  can.cd(9);
  framecut_bMes->Draw();

  can.cd(10);
  framecut_bDeltaE->Draw();

  can.Print("fig/rareBdecay.eps");
}

